@@ -1,3 +1,4 @@
+
 /* FeatureWeights.c
  *
  * Copyright (C) 2007-2008 Ola Söder
@@ -17,6 +18,13 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+/* $URL: svn://pegasos.dyndns.biz/praat/trunk/kNN/FeatureWeights.c $
+ * $Rev: 137 $
+ * $Author: stix $
+ * $Date: 2008-08-10 19:34:07 +0200 (Sun, 10 Aug 2008) $
+ * $Id: FeatureWeights.c 137 2008-08-10 17:34:07Z stix $
+ */
+
 /*
  * os 20070529 Initial release
  */
@@ -217,8 +225,8 @@ FeatureWeights FeatureWeights_computeWrapperInt
                 {
                     for (long y = 0; y < nseeds; y++)
                     {
-                        cs[y]->fweights->data[1][x] = NUMrandomUniform(OlaMAX(0, cs[nseeds]->fweights->data[1][x] - range),
-                                                      OlaMIN(1, cs[nseeds]->fweights->data[1][x] + range));
+                        cs[y]->fweights->data[1][x] = NUMrandomUniform(MAX(0, cs[nseeds]->fweights->data[1][x] - range),
+                                                      MIN(1, cs[nseeds]->fweights->data[1][x] + range));
                         results[y] = KNN_evaluate(me, cs[y], k, d, emode);
                     }
                     for (long q = 0; q < nseeds; q++)
@@ -238,8 +246,8 @@ FeatureWeights FeatureWeights_computeWrapperInt
                 {
                     for (long x = 1; x <= (my input)->nx; x++)
                     {
-                        cs[y]->fweights->data[1][x] = NUMrandomUniform(OlaMAX(0, cs[nseeds]->fweights->data[1][x] - range),
-                                                      OlaMIN(1, cs[nseeds]->fweights->data[1][x] + range));
+                        cs[y]->fweights->data[1][x] = NUMrandomUniform(MAX(0, cs[nseeds]->fweights->data[1][x] - range),
+                                                      MIN(1, cs[nseeds]->fweights->data[1][x] + range));
                     }
                     results[y] = KNN_evaluate(me, cs[y], k, d, emode);
                 }
@@ -332,8 +340,8 @@ FeatureWeights FeatureWeights_computeWrapperExt
                 {
                     for (long y = 0; y < nseeds; y++)
                     {
-                        cs[y]->fweights->data[1][x] = NUMrandomUniform(OlaMAX(0, cs[nseeds]->fweights->data[1][x] - range),
-                                                      OlaMIN(1, cs[nseeds]->fweights->data[1][x] + range));
+                        cs[y]->fweights->data[1][x] = NUMrandomUniform(MAX(0, cs[nseeds]->fweights->data[1][x] - range),
+                                                      MIN(1, cs[nseeds]->fweights->data[1][x] + range));
                         results[y] = FeatureWeights_evaluate(cs[y], nn, pp, c, k, d);
                     }
                     for (long q = 0; q < nseeds; q++)
@@ -353,8 +361,8 @@ FeatureWeights FeatureWeights_computeWrapperExt
                 {
                     for (long x = 1; x <= pp->nx; x++)
                     {
-                        cs[y]->fweights->data[1][x] = NUMrandomUniform(OlaMAX(0, cs[nseeds]->fweights->data[1][x] - range),
-                                                      OlaMIN(1, cs[nseeds]->fweights->data[1][x] + range));
+                        cs[y]->fweights->data[1][x] = NUMrandomUniform(MAX(0, cs[nseeds]->fweights->data[1][x] - range),
+                                                      MIN(1, cs[nseeds]->fweights->data[1][x] + range));
                     }
                     results[y] = FeatureWeights_evaluate(cs[y], nn, pp, c, k, d);
                 }
