@@ -28,8 +28,19 @@
 //                                                 //
 /////////////////////////////////////////////////////
 
-int KNN_getNumberOfCPUs();
+// Error codes
+enum KNN_thread_status
+{
+    KNN_THREAD_OK,
+    KNN_THREAD_ERROR
+};
 
+// Query the number of available CPUs
+int KNN_getNumberOfCPUs(void);
+
+// Distribute the work specified by 
+// (*function) and input over nthreads 
+// threads
 void * KNN_threadDistribution
 (
     void * (* function) (void *), 
@@ -37,8 +48,10 @@ void * KNN_threadDistribution
     int nthreads
 );
 
-void KNN_threadTest();
+// Test threading
+void KNN_threadTest(void);
 
+// Test threading aux
 void * KNN_threadTestAux
 (
     void * dummy
