@@ -405,8 +405,6 @@ FORM (KNN_evaluateWithTestSet, L"Evaluation", L"KNN & Pattern & Categories: Eval
 
 DO
     KNN  me = ONLY(classKNN);
-    ASSERT(my nInstances >= 0);
-
     if (my nInstances < 1)
         return Melder_error ("Instance base is empty", 0);
 
@@ -515,8 +513,6 @@ FORM (KNN_toCategories, L"Classification", L"KNN & Pattern: To Categories...")
 
 DO
     KNN  me = ONLY(classKNN);
-    ASSERT(my nInstances >= 0);
-
     if (my nInstances < 1)
         return Melder_error ("Instance base is empty", 0);
 
@@ -852,8 +848,6 @@ FORM (FeatureWeights_computeWrapperExt, L"Feature weights", L"KNN & Pattern & Ca
 
 DO
     KNN  me = ONLY(classKNN);
-    ASSERT(my nInstances >= 0);
-
     if (my nInstances < 1)
         return Melder_error ("Instance base is empty", 0);
 
@@ -986,6 +980,8 @@ END
 // DEBUG                                                                               //
 /////////////////////////////////////////////////////////////////////////////////////////
 
+// Disabled
+/*
 #ifdef _DEBUG
 
 DIRECT (KNN_debug_KNN_SA_partition)
@@ -1016,12 +1012,11 @@ DIRECT (KNN_debug_KNN_getNumberOfCPUs)
 END
 
 DIRECT (KNN_debug_KNN_threadTest)
-    KNN_threadTest(NULL);
+    KNN_threadTest();
 END
 
-
 #endif
-
+*/
 
 
 
@@ -1146,6 +1141,7 @@ void praat_contrib_Ola_KNN_init (void)
 // DEBUG //
 ///////////
 
+/*
 #ifdef _DEBUG
 
     praat_addAction1 (classKNN, 0, L"_DEBUG: KNN_getNumberOfCPUs", 0, 0, DO_KNN_debug_KNN_getNumberOfCPUs);
@@ -1153,6 +1149,7 @@ void praat_contrib_Ola_KNN_init (void)
     praat_addAction1 (classPattern, 1, L"_DEBUG: KNN_SA_partition", 0, 1, DO_KNN_debug_KNN_SA_partition);
 
 #endif
+*/
 
 ///////////
 // Hints //
